from django import test
from django import template

from pseudo_cms import models

__all__ = ('PageContentTagTests', )


class PageContentTagTests(test.TestCase):
    def test_adds_page_content_to_context(self):
        url = "/path/to/something/"
        content = models.Content.objects.create(url=url, title="My Title")

        t = template.Template(
            """{% load pseudo_cms_tags %}{% page_content path as content %}
        <h1>{{ content.title }}</h1>
        """)
        result = t.render(template.Context({'path': url}))

        self.assertHTMLEqual("<h1>{0.title}</h1>".format(content), result)



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):
    def forwards(self, orm):

        # Adding model 'Content'
        db.create_table(
            'pseudo_cms_content', (
                ('id', self.gf('django.db.models.fields.AutoField')(
                    primary_key=True)),
                ('url', self.gf('django.db.models.fields.CharField')(
                    unique=True, max_length=200)),
                ('title',
                 self.gf('django.db.models.fields.CharField')(max_length=60)),
                ('meta_description',
                 self.gf('django.db.models.fields.CharField')(max_length=200)),
                ('page_title',
                 self.gf('django.db.models.fields.CharField')(max_length=60)),
                ('body', self.gf('django.db.models.fields.TextField')()),
                ('image', self.gf('image_helper.fields.SizedImageField')(
                    max_length=100, blank=True)),
            ))
        db.send_create_signal('pseudo_cms', ['Content'])

    def backwards(self, orm):

        # Deleting model 'Content'
        db.delete_table('pseudo_cms_content')

    models = {
        'pseudo_cms.content': {
            'Meta': {
                'ordering': "('url',)",
                'object_name': 'Content'
            },
            'body': ('django.db.models.fields.TextField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {
                'primary_key': 'True'
            }),
            'image': ('image_helper.fields.SizedImageField', [], {
                'max_length': '100',
                'blank': 'True'
            }),
            'meta_description': ('django.db.models.fields.CharField', [], {
                'max_length': '200'
            }),
            'page_title': ('django.db.models.fields.CharField', [], {
                'max_length': '60'
            }),
            'title': ('django.db.models.fields.CharField', [], {
                'max_length': '60'
            }),
            'url': ('django.db.models.fields.CharField', [], {
                'unique': 'True',
                'max_length': '200'
            })
        }
    }

    complete_apps = ['pseudo_cms']



from django.core.exceptions import ValidationError
from django.urls import resolve
from django.http import Http404


def internal_path_exists(path):
    """
    Validates that url path is registered and can properly be resolved
    in a django configuration.
    """
    try:
        resolve(path)
    except Http404:
        raise ValidationError("'{0}' is not a valid url.".format(path))



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import DataMigration
from django.db import models

from pseudo_cms.utils import convert_to_html


class Migration(DataMigration):
    def forwards(self, orm):
        # saving will force the conversion of body content to body_html
        for c in orm.Content.objects.all():
            c.body_html = convert_to_html(c.body, c.content_format)
            c.save()

    def backwards(self, orm):
        "Write your backwards methods here."

    models = {
        'pseudo_cms.content': {
            'Meta': {
                'ordering': "('url',)",
                'object_name': 'Content'
            },
            'body': ('django.db.models.fields.TextField', [], {}),
            'body_html': ('django.db.models.fields.TextField', [], {}),
            'content_format': ('django.db.models.fields.CharField', [], {
                'default': "u'text'",
                'max_length': '50'
            }),
            'id': ('django.db.models.fields.AutoField', [], {
                'primary_key': 'True'
            }),
            'image': ('image_helper.fields.SizedImageField', [], {
                'max_length': '100',
                'blank': 'True'
            }),
            'meta_description': ('django.db.models.fields.CharField', [], {
                'max_length': '200'
            }),
            'page_title': ('django.db.models.fields.CharField', [], {
                'max_length': '60'
            }),
            'title': ('django.db.models.fields.CharField', [], {
                'max_length': '100'
            }),
            'url': ('django.db.models.fields.CharField', [], {
                'unique': 'True',
                'max_length': '200'
            })
        }
    }

    complete_apps = ['pseudo_cms']
    symmetrical = True



from django.contrib import admin
from django.utils.safestring import mark_safe

from image_helper.fields import SizedImageField
from image_helper.widgets import AdminImagePreviewWidget

from pseudo_cms import models


class ContentAdmin(admin.ModelAdmin):
    list_display = ['thumbnail', 'url', 'title', 'page_title']
    search_fields = ['title', 'page_title', 'body', 'meta_description']
    exclude = ('body_html', )

    fieldsets = (('', {
        'fields': ('url', )
    }), ('Search Engine Fields', {
        'fields': ('title', 'meta_description'),
    }), ('Page Content', {
        'fields': ('page_title', 'page_tagline', 'content_format', 'body',
                   'image'),
    }))

    def thumbnail(self, obj):
        """Thumbnail for list display preview"""
        if obj.image:
            thumbnail_url = obj.image.thumbnail.url
            return mark_safe(
                '<img src="{0}" width="100" alt="thumbnail" />'.format(
                    thumbnail_url))
        else:
            return ''

    formfield_overrides = {
        SizedImageField: {
            'widget': AdminImagePreviewWidget
        }
    }


admin.site.register(models.Content, ContentAdmin)



from django.conf.urls import url
from django.http import HttpResponse


def test_path_view(request):
    return HttpResponse("OK")


urlpatterns = [
    url("^tests/path-one/$", test_path_view, name="test_path"),
]



from setuptools import setup, find_packages


from pseudo_cms import VERSION

setup(
    name="django-pseudo-cms",
    version=VERSION,
    author="Aaron Madison",
    description="A Simple application to help add dynamic content to pages.",
    long_description=open('README.rst', 'r').read(),
    url="https://github.com/madisona/django-pseudo-cms",
    packages=find_packages(exclude=["example"]),
    install_requires=open('requirements/requirements.txt').read().splitlines(),
    zip_safe=False,
    classifiers = [
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],
)



from django.conf import settings
from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from image_helper.fields import SizedImageField

from pseudo_cms.validators import internal_path_exists
from pseudo_cms import utils

# You may change the image size in settings if you wish.
IMAGE_SIZE = getattr(settings, "PSEUDO_CMS_IMAGE_SIZE", (600, 450))
THUMBNAIL_SIZE = getattr(settings, "PSEUDO_CMS_THUMBNAIL_SIZE", (176, 132))


@python_2_unicode_compatible
class Content(models.Model):
    url = models.CharField(
        max_length=200,
        unique=True,
        validators=[internal_path_exists],
        help_text="URL endpoint of page content belongs to.",
        db_index=True)
    title = models.CharField(
        max_length=100,
        help_text="Title that shows on searches / browser tab.")
    meta_description = models.CharField(
        max_length=200, help_text="Description that shows in search engine.")

    page_title = models.CharField(
        max_length=60, help_text="Title that shows on page.")
    page_tagline = models.CharField(
        max_length=120, help_text="Tagline / Subtitle for page", blank=True)
    content_format = models.CharField(
        choices=utils.CONTENT_FORMAT_CHOICES,
        max_length=50,
        default=utils.PLAIN_TEXT)
    body = models.TextField()
    body_html = models.TextField()

    image = SizedImageField(
        blank=True,
        upload_to="cms/content",
        size=IMAGE_SIZE,
        thumbnail_size=THUMBNAIL_SIZE)

    class Meta(object):
        ordering = ('url', )

    def __str__(self):
        return self.url

    def save(self, *args, **kwargs):
        self.body_html = utils.convert_to_html(self.body, self.content_format)
        return super(Content, self).save(*args, **kwargs)

    @classmethod
    def get_for_page(cls, page_url):
        try:
            return cls.objects.get(url=page_url)
        except cls.DoesNotExist:
            return None
